
import ArchetypesHack

def initialize(context):
    """Initializer called when used as a Zope 2 product."""
    pass

from AccessControl import allow_class, allow_module
allow_module('MegamanicEdit.MegamanicEdit.FakeRequest')

import monkey_patches



from Products.Archetypes.Schema import Schemata

old_filterFields = Schemata.filterFields.im_func

def filterFields(self, *predicates, **values):
    result = old_filterFields(self, *predicates, **values)
    result2 = []
    this = self.this()
    if hasattr(this.aq_base, 'isMegamanicEditable') and \
            this.isMegamanicEditable():
        for field in result:
            try:
                if field.getAccessor(self)() !=\
                        field.default:
                    result2.append(field)
            except:
                # Something went wrong, but the
                # field was available so lets
                # juts pass it along
                result2.append(field)
#        import pdb; pdb.set_trace()
        return result2
    return result

Schemata.filterFields = filterFields



## Script (Python) "get_megamanic_editable_objects"
##title=Get objects that can be edited with MegamanicEdit
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=where,include_self=True

from Products.CMFCore.utils import getToolByName
interface = getToolByName(container, 'portal_interface')

#MegamanicEditable = 'MegamanicEdit.MegamanicEdit.MegamanicEdit.interfaces.MegamanicEditableObject'

editable = []

if include_self:
    editable.append(where)

for object in where.contentValues():
    # For some reason this doesn't work, so we hack it
    #if interface.objectImplements(object, MegamanicEditable):
    MegamanicEditable = getattr(object, 'isMegamanicEditable', '')
    if MegamanicEditable and MegamanicEditable(object):
        editable.append(object)

return editable



from Products.Archetypes.Field import Field

checkPermissionOld = Field.checkPermission

def checkPermission(self, mode, instance):
    """Hacks access to add widgets.."""
    aatvew = getattr(instance, 'anonymousAllowedToViewEditWidget', None)
    if aatvew and callable(aatvew) and aatvew.im_func(instance):
        return True
    else:
        return checkPermissionOld(self, mode, instance)

Field.checkPermission = checkPermission
